/* BdfServer_Commands - Copyright (c) 2023 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.exportation;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.managers.AccessManager;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfCommandUtils;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import net.fichotheque.exportation.access.AccessDef;
import net.fichotheque.tools.exportation.access.AccessDefBuilder;
import net.mapeadores.util.attr.AttributeParser;
import net.mapeadores.util.logging.ErrorMessageException;
import net.mapeadores.util.request.RequestMap;
import net.mapeadores.util.text.Label;
import net.mapeadores.util.text.LabelChange;


/**
 *
 * @author Vincent Calame
 */
public class AccessChangeCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "AccessChange";
    public final static String COMMANDKEY = "_ EXP-63";
    public final static String TABLEEXPORTNAME_PARAMNAME = "tableexportname";
    public final static String SELECTIONDEFNAME_PARAMNAME = "selectiondefname";
    public final static String PUBLIC_PARAMNAME = "public";
    public final static String QUERY_XML_PARAMNAME = "query_xml";
    public final static String TITLE_PARAMPREFIX = "title/";
    public final static String ATTRIBUTES_PARAMNAME = "attributes";
    private AccessDef accessDef;

    public AccessChangeCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() {
        AccessManager accessManager = bdfServer.getAccessManager();
        accessManager.putAccessDef(accessDef);
        putResultObject(ACCESSDEF_OBJ, accessDef);
        setDone("_ done.exportation.accesschange", accessDef.getName());
    }

    @Override
    protected void checkParameters() throws ErrorMessageException {
        checkFichothequeAdmin();
        AccessManager sqlExportManager = bdfServer.getAccessManager();
        AccessDef currentAccessDef = BdfInstructionUtils.getMandatoryAccessDef(sqlExportManager, requestMap);
        String tableExportName = getMandatory(TABLEEXPORTNAME_PARAMNAME);
        String selectionDefName = requestMap.getParameter(SELECTIONDEFNAME_PARAMNAME);
        boolean publicAccess = requestMap.isTrue(PUBLIC_PARAMNAME);
        AccessDefBuilder accessDefBuilder = AccessDefBuilder.init(currentAccessDef.getName())
                .setSelectionDefName(selectionDefName)
                .setTableExportName(tableExportName)
                .setPublic(publicAccess);
        BdfCommandUtils.parseQueries(fichotheque, getMandatory(QUERY_XML_PARAMNAME), accessDefBuilder.getCustomFichothequeQueriesBuilder());
        LabelChange labelChange = BdfCommandUtils.getLabelChange(requestMap, TITLE_PARAMPREFIX);
        for (Label label : labelChange.getChangedLabels()) {
            accessDefBuilder.putLabel(label);
        }
        String attributes = requestMap.getParameter(ATTRIBUTES_PARAMNAME);
        if (attributes != null) {
            accessDefBuilder.getAttributesBuilder().changeAttributes(AttributeParser.parse(attributes));
        }
        this.accessDef = accessDefBuilder.toAccessDef();
    }

}
